__productname__ = "alot-plugin-checkmail"
__version__ = "0.0.15"
__copyright__ = "Copyright (c) 2021 Torgny Bjers"
__author__ = "Torgny Bjers"
__author_email__ = "torgny@bjers.org"
__description__ = "Command wrapper with feedback for checking mail and other long-running tasks."
__url__ = "https://github.com/tbjers/alot-plugin-checkmail"
__license__ = "Licensed under the MIT license."
